#
# spec file for package openSUSE-repos
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2022 Neal Gompa <ngompa13@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global debug_package %{nil}

%if "openSUSE-repos-Tumbleweed" == ""
ExclusiveArch:  do_not_build
%endif

# Each openSUSE release package has a suggests for openSUSE-repos-$flavor.
%global flavor openSUSE-repos-Tumbleweed%nil

%define with_nvidia 1
%if 0%{?is_opensuse} && 0%{?suse_version} > 1600
# Tumbleweed
%if "%flavor" == "openSUSE-repos-Tumbleweed"
%define theme Tumbleweed
%define branding tumbleweed
%endif
%if "%flavor" == "openSUSE-repos-Slowroll"
%define theme Slowroll
%define branding slowroll
%endif
%if "%flavor" == "openSUSE-repos-MicroOS"
%define theme MicroOS
%define branding microos
%endif
%endif

# LeapMicro 6.0 does not have sle_version any more
%if 0%{?is_leapmicro}
%if "%flavor" == "openSUSE-repos-LeapMicro"
%define theme LeapMicro
%define branding leap-micro
# Do not build for LeapMicro as per SLEM Product Management
# They expect NVIDIA related drivers and libs to be present inside the container
%define with_nvidia 0
%endif
%else
# Leap
%if 0%{?sle_version}
%if "%flavor" == "openSUSE-repos-Leap"
%define theme Leap
%define branding leap
%endif
%endif
%endif

# Leap 16
%if 0%{?is_opensuse} && 0%{?suse_version} >= 1600 && !0%{?is_leapmicro}
%if "%flavor" == "openSUSE-repos-Leap"
%define theme Leap
%define branding leap
%define with_nvidia 0
%endif
%endif

%if "%{?theme}" == ""
ExclusiveArch:  do_not_build
%endif

%if "openSUSE-repos-Tumbleweed" == ""
Name:           openSUSE-repos
%else
Name:           openSUSE-repos-%{theme}
%endif
Version:        20250303.f74564e
Release:        1.1
Summary:        openSUSE package repositories
License:        MIT
Group:          System/Management
URL:            https://github.com/openSUSE/openSUSE-repos
Source:         openSUSE-repos-%{version}.tar.xz
#boo#1203715

Requires:       zypper
# Ensure we install matching packages on given distribution
# openSUSE-release has suggest on particular theme based on distribution
%if 0%{?with_nvidia}
Suggests:       openSUSE-repos-%{theme}-NVIDIA
%endif
Conflicts:      otherproviders(openSUSE-repos)
Provides:       openSUSE-repos
%if "%{?theme}" == "Tumbleweed"
Obsoletes:      openSUSE-repos-Leap
Obsoletes:      openSUSE-repos-LeapMicro
%endif
%if "%{?theme}" == "Slowroll"
Obsoletes:      openSUSE-repos-Leap
Obsoletes:      openSUSE-repos-LeapMicro
%endif
%if "%{?theme}" == "MicroOS"
Obsoletes:      openSUSE-repos-Leap
Obsoletes:      openSUSE-repos-LeapMicro
%endif

%description
Definitions for openSUSE repository management via zypp-services

%if 0%{?with_nvidia}
%package NVIDIA
Summary:        openSUSE NVIDIA repository definitions
Requires:       openSUSE-repos-%{theme}
Supplements:    modalias(pci:v000010DEd*sv*sd*bc03sc*i*)
Provides:       openSUSE-repos-NVIDIA
Conflicts:      otherproviders(openSUSE-repos-NVIDIA)

# Issue 62: Ensure package gets removed on migration
# to commercial products
Conflicts:      product(SLES)
Conflicts:      product(SL-Micro)
Conflicts:      product(SLE-Micro)
Conflicts:      product(SLED)

%if "%{?theme}" == "Tumbleweed"
Obsoletes:      openSUSE-repos-Leap-NVIDIA
Obsoletes:      openSUSE-repos-LeapMicro-NVIDIA
%endif
%if "%{?theme}" == "MicroOS"
Obsoletes:      openSUSE-repos-Leap-NVIDIA
Obsoletes:      openSUSE-repos-LeapMicro-NVIDIA
%endif

%description NVIDIA
Definitions for NVIDIA repository management via zypp-services
%endif

%files

%dir %{_datadir}/zypp/local/
%dir %{_datadir}/zypp/local/service
%dir %{_datadir}/zypp/local/service/openSUSE
%dir %{_datadir}/zypp/local/service/openSUSE/repo
%ghost %{_datadir}/zypp/local/service/openSUSE/repo/repoindex.xml
%ghost %{_sysconfdir}/zypp/services.d/openSUSE.service
%{_sysconfdir}/zypp/vars.d/DIST_ARCH
%{_sysconfdir}/profile.d/opensuse_repos.sh

%if "%{theme}" == "Tumbleweed"
%ifarch %{ix86} x86_64
%{_datadir}/zypp/local/service/openSUSE/repo/opensuse-%{branding}-repoindex.xml
%else
%{_datadir}/zypp/local/service/openSUSE/repo/opensuse-%{branding}-ports-repoindex.xml
%endif
%endif

%if "%{theme}" == "Slowroll"
%ifarch x86_64
%{_datadir}/zypp/local/service/openSUSE/repo/opensuse-%{branding}-repoindex.xml
%endif
%endif

%if "%{theme}" == "MicroOS"
%ifarch x86_64 aarch64
%{_datadir}/zypp/local/service/openSUSE/repo/opensuse-%{branding}-repoindex.xml
%endif
%endif

%if "%{theme}" == "LeapMicro"
%ifarch x86_64 aarch64
%{_datadir}/zypp/local/service/openSUSE/repo/opensuse-%{branding}-repoindex.xml
%endif
%endif

%if "%{theme}" == "Leap"
%ifarch %{ix86} x86_64 aarch64 ppc64le s390x
%{_datadir}/zypp/local/service/openSUSE/repo/opensuse-%{branding}-repoindex.xml
%else
%{_datadir}/zypp/local/service/openSUSE/repo/opensuse-%{branding}-ports-repoindex.xml
%endif
%endif

%if 0%{?with_nvidia}
%files NVIDIA
%dir %{_datadir}/zypp/local/service/NVIDIA
%dir %{_datadir}/zypp/local/service/NVIDIA/repo
%ghost %{_datadir}/zypp/local/service/NVIDIA/repo/repoindex.xml
%{_datadir}/zypp/local/service/NVIDIA/repo/nvidia-%{branding}-repoindex.xml
%ghost %{_sysconfdir}/zypp/services.d/openSUSE.service
%{_datadir}/zypp/local/service/NVIDIA/repo/nvidia-%{branding}-repoindex.xml
%endif

%prep
%setup -q -n openSUSE-repos-%{version}

%build
# Nothing to build

%install

mkdir -p %{buildroot}%{_datadir}/zypp/local/service/openSUSE/repo
mkdir -p %{buildroot}%{_datadir}/zypp/local/service/NVIDIA/repo
mkdir -p %{buildroot}%{_sysconfdir}/zypp/vars.d/

mkdir -p %{buildroot}%{_sysconfdir}/profile.d
install opensuse_repos.sh %{buildroot}%{_sysconfdir}/profile.d

# Setup for primary arches
%if "%{theme}" == "Tumbleweed"
%ifarch %{ix86} x86_64
install opensuse-%{branding}-repoindex.xml -pm 0644 %{buildroot}%{_datadir}/zypp/local/service/openSUSE/repo
%else
install opensuse-%{branding}-ports-repoindex.xml -pm 0644 %{buildroot}%{_datadir}/zypp/local/service/openSUSE/repo
%endif
%endif

%if "%{theme}" == "Slowroll"
%ifarch x86_64
install opensuse-%{branding}-repoindex.xml -pm 0644 %{buildroot}%{_datadir}/zypp/local/service/openSUSE/repo
%endif
%endif

%if "%{theme}" == "MicroOS"
%ifarch x86_64 aarch64
install opensuse-%{branding}-repoindex.xml -pm 0644 %{buildroot}%{_datadir}/zypp/local/service/openSUSE/repo
%endif
%endif

%if "%{theme}" == "LeapMicro"
%ifarch x86_64 aarch64
%if 0%{?suse_version} >= 1600
# Micro 6.X
install opensuse-%{branding}6-repoindex.xml -pm 0644 %{buildroot}%{_datadir}/zypp/local/service/openSUSE/repo/opensuse-%{branding}-repoindex.xml
%else
# Micro 5.X
install opensuse-%{branding}5-repoindex.xml -pm 0644 %{buildroot}%{_datadir}/zypp/local/service/openSUSE/repo/opensuse-%{branding}-repoindex.xml
%endif
%endif
%endif

%if "%{theme}" == "Leap"
# Leap 16
%if 0%{?is_opensuse} && 0%{?suse_version} == 1600
install opensuse-%{branding}16-repoindex.xml -pm 0644 %{buildroot}%{_datadir}/zypp/local/service/openSUSE/repo/opensuse-%{branding}-repoindex.xml
%else
%ifarch %{ix86} x86_64 aarch64 ppc64le s390x
install opensuse-%{branding}-repoindex.xml -pm 0644 %{buildroot}%{_datadir}/zypp/local/service/openSUSE/repo
%else
install opensuse-%{branding}-ports-repoindex.xml -pm 0644 %{buildroot}%{_datadir}/zypp/local/service/openSUSE/repo
%endif
%endif
%endif

%if 0%{?with_nvidia}
install nvidia-%{branding}-repoindex.xml -pm 0644 %{buildroot}%{_datadir}/zypp/local/service/NVIDIA/repo
%endif

%ifarch %{ix86}
echo "x86" >  %{buildroot}%{_sysconfdir}/zypp/vars.d/DIST_ARCH
%endif

%ifarch x86_64
echo "x86_64" >  %{buildroot}%{_sysconfdir}/zypp/vars.d/DIST_ARCH
%endif

%ifarch aarch64
echo "aarch64" >  %{buildroot}%{_sysconfdir}/zypp/vars.d/DIST_ARCH
%endif

%ifarch armv6l armv6hl
echo "armv6hl" >  %{buildroot}%{_sysconfdir}/zypp/vars.d/DIST_ARCH
%endif

%ifarch armv7l armv7hl
echo "armv7hl" >  %{buildroot}%{_sysconfdir}/zypp/vars.d/DIST_ARCH
%endif

%ifarch ppc ppc64 ppc64le
echo "ppc" >  %{buildroot}%{_sysconfdir}/zypp/vars.d/DIST_ARCH
%endif

%ifarch riscv64
echo "riscv" >  %{buildroot}%{_sysconfdir}/zypp/vars.d/DIST_ARCH
%endif

%ifarch s390x
echo "zsystems" >  %{buildroot}%{_sysconfdir}/zypp/vars.d/DIST_ARCH
%endif

%post
# Disable all non-zypp-service managed repos with default filenames
for repo_file in \
repo-backports-debug-update.repo repo-oss.repo repo-backports-update.repo \
repo-sle-debug-update.repo repo-debug-non-oss.repo repo-sle-update.repo \
repo-debug.repo repo-source.repo repo-debug-update.repo repo-update.repo \
repo-debug-update-non-oss.repo repo-update-non-oss.repo repo-non-oss.repo \
download.opensuse.org-oss.repo download.opensuse.org-non-oss.repo download.opensuse.org-tumbleweed.repo \
repo-openh264.repo openSUSE-*-0.repo repo-main.repo; do
  if [ -f %{_sysconfdir}/zypp/repos.d/$repo_file ]; then
    echo "Content of $repo_file will be newly managed by zypp-services."
    echo "Storing old copy as %{_sysconfdir}/zypp/repos.d/$repo_file.rpmsave"
    mv %{_sysconfdir}/zypp/repos.d/$repo_file %{_sysconfdir}/zypp/repos.d/$repo_file.rpmsave
  fi
done

# Needs to be called after postun of old package or we might endup with
# No service and no repos as there is a symlink and service removal in postun of old pkg
%posttrans
%if "%{theme}" == "Tumbleweed"
%ifarch %{ix86} x86_64
ln -sf opensuse-%{branding}-repoindex.xml %{_datadir}/zypp/local/service/openSUSE/repo/repoindex.xml
%else
ln -sf opensuse-%{branding}-ports-repoindex.xml %{_datadir}/zypp/local/service/openSUSE/repo/repoindex.xml
%endif
%endif

%if "%{theme}" == "Slowroll"
%ifarch x86_64
ln -sf opensuse-%{branding}-repoindex.xml %{_datadir}/zypp/local/service/openSUSE/repo/repoindex.xml
%endif
%endif

%if "%{theme}" == "MicroOS"
%ifarch x86_64 aarch64
ln -sf opensuse-%{branding}-repoindex.xml %{_datadir}/zypp/local/service/openSUSE/repo/repoindex.xml
%endif
%endif

%if "%{theme}" == "LeapMicro"
%ifarch x86_64 aarch64
ln -sf opensuse-%{branding}-repoindex.xml %{_datadir}/zypp/local/service/openSUSE/repo/repoindex.xml
%endif
%endif

%if "%{theme}" == "Leap"
%ifarch %{ix86} x86_64 aarch64 ppc64le s390x
ln -sf opensuse-%{branding}-repoindex.xml %{_datadir}/zypp/local/service/openSUSE/repo/repoindex.xml
%else
ln -sf opensuse-%{branding}-ports-repoindex.xml %{_datadir}/zypp/local/service/openSUSE/repo/repoindex.xml
%endif
%endif

# We hereby declare that running this will not influence existing transaction
ZYPP_READONLY_HACK=1 zypper addservice %{_datadir}/zypp/local/service/openSUSE openSUSE
ZYPP_READONLY_HACK=1 zypper refresh-services

%if 0%{?with_nvidia}
%posttrans NVIDIA
ln -sf nvidia-%{branding}-repoindex.xml %{_datadir}/zypp/local/service/NVIDIA/repo/repoindex.xml

# Disable user-defined with default filename from wiki
# https://en.opensuse.org/SDB:NVIDIA_drivers#Zypper
for repo_file in NVIDIA.repo ; do
  if [ -f %{_sysconfdir}/zypp/repos.d/$repo_file ]; then
    echo "Content of $repo_file will be newly managed by zypp-services."
    echo "Storing old copy as {_sysconfdir}/zypp/repos.d/$repo_file.rpmsave"
    mv %{_sysconfdir}/zypp/repos.d/$repo_file %{_sysconfdir}/zypp/repos.d/$repo_file.rpmsave
  fi
done

# We hereby declare that running this will not influence existing transaction
ZYPP_READONLY_HACK=1 zypper addservice %{_datadir}/zypp/local/service/NVIDIA NVIDIA
ZYPP_READONLY_HACK=1 zypper refresh-services
%endif

%postun
if [ "$1" = 0 ] ; then
  # We hereby declare that running this will not influence existing transaction
  ZYPP_READONLY_HACK=1 zypper removeservice openSUSE
  if [ -L "%{_datadir}/zypp/local/service/openSUSE/repo/repoindex.xml" ] ; then
    rm -f %{_datadir}/zypp/local/service/openSUSE/repo/repoindex.xml
  fi
fi

%if 0%{?with_nvidia}
%postun NVIDIA
if [ "$1" = 0 ] ; then
  # We hereby declare that running this will not influence existing transaction
  ZYPP_READONLY_HACK=1 zypper removeservice NVIDIA
  if [ -L "%{_datadir}/zypp/local/service/NVIDIA/repo/repoindex.xml" ] ; then
    rm -f %{_datadir}/zypp/local/service/NVIDIA/repo/repoindex.xml
  fi
fi
%endif

%changelog
* Mon Mar  3 2025 opensuse-releaseteam@opensuse.org
- Update to version 20250303.f74564e:
  * Enable experimental parallel downloads for Leap and TW (#79)
  * Fix $arch -> $basearch for Leap 16.0
  * Add /etc/profile.d/opensuse_repos.sh
* Thu Feb 20 2025 opensuse-releaseteam@opensuse.org
- Update to version 20250220.13a9986:
  * Use arch specific repodata on Leap 16.0 (#77)
* Tue Feb  4 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.20: the construct %%else ifarch … was never
  valid; anything behing 'else' was simply ignored and now leads to
  an error.
* Mon Dec  9 2024 Lubos Kocman <Lubos.Kocman+factory@suse.de>
- Disable Leap flavor building on Leap Micro 6.1+
  which newly contains sle_version
* Mon Dec  9 2024 Lubos Kocman <lubos.kocman@suse.com>
- Make new symlink and zypper addservice in postrans
  * To ensure that addition of service and symlink creation
    is executed only after the postun of old package.
    Otherwise we end up with no service and no repoindex symlink.
  * This supports migration from LeapMicro to MicroOS
  * Fixes gh#openSUSE/opensuse-migration-tool#17
* Fri Jul 12 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240712.dd8c2eb:
  * use cdn.opensuse.org for leap16
* Fri Jul 12 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240712.d0ece36:
  * Update opensuse-leap16-repoindex.xml to use distribution (#71)
* Wed Jul 10 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240710.603d305 boo#1227625:
  * Fix missing quote in opensuse-leap16-repoindex.xml (#68)
* Thu Jul  4 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240704.2072b16:
  * Working Leap 16 repoindex with standard + product repo (#67)
  * Add ports non-oss non-oss/sources for TW (#65) boo#1226763
* Tue Jun 25 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240625.f75b6e5:
  * initial leap 16 repoindex
  * Update README.md
- Handle Leap 16 similar to LEAPM 5 vs 6
* Mon Jun 24 2024 Lubos Kocman <lubos.kocman@suse.com>
- Ensure that refresh-services / refs is called after addservice
* Mon Jun 24 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240621.6fd1ef2:
  * Update README.md
  * use osc service mr for update
  * Disable source and debug repos by default for Tumbleweed ports
  * Use cdn.opensuse.org for Tumbleweed ports
* Thu Jun 20 2024 Lubos Kocman <lubos.kocman@suse.com>
- Ensure package gets removed on migration to commmercial products
  Issue #62 on gh
- Update _service file's set_version and obs_scm to manual
  spec will be now updated by running osc service mr
* Tue Jun 18 2024 Lubos Kocman <lubos.kocman@suse.com>
- Add Leap Micro 6.X 5.X handling
  * no dedicated update repo for slem updates.
  * oss repo will now always include slem 6.X updates
* Tue Jun 18 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240618.8c4e429:
  * keep micro5 in micro5 repoindex
- Update to version 20240618.727f0a2:
  * Use new path names for micro 6.0
  * use 6.0 for leap-micro6 repoindex
  * Add repoindex for Micro 6
  * Update README.md with openqa reference
  * Update README.md with --gpg-auto-import-keys
  * Remove reference to undefined substitution
* Mon May 20 2024 Andreas Schwab <schwab@suse.de>
- Fix macro reference
* Thu May 16 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240516.5431918:
  * Update README.md
  * ci: Use bash for repo_checks to not rely on shebang
  * t: Add diagnostic to leap test
  * Add ci
  * Add basic url_checker
  * repo_checks: Add handling for Leap and Leap Micro
  * Drop Leap armv7hl debug repo definitions boo#1224217
  * Use Leap source repo for Leap 15 ports
  * Fix urls for leap-ports (32 bit arm)
  * Create repo_checks.yml
  * rename url_checker to repo_checks
  * Drop leap16 definitions for now to get url_checker working
* Fri May 10 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240510.6bfa644:
  * Update nvidia-leap-repoindex.xml
  * Leap add missing slash after distsub
  * Update README.md
* Mon Apr 29 2024 Lubos Kocman <lubos.kocman@suse.com>
- Ensure that only one NVIDIA package flavor can be installed
  Related to Issue #53
* Fri Apr 26 2024 opensuse-releaseteam@opensuse.org
- NVIDIA package needs to require specific flavor. Issue #53
* Fri Apr 12 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240412.89bd714:
  * Update opensuse-leap-micro-repoindex.xml
* Fri Apr 12 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240412.c2caafb:
  * Drop specfile from git
  * remove an extra slash in 'nvidia-slowroll-repoindex.xml' file
  * deleted an extra slash in the repository files
  * Ensure that LeapMicro flavor is built
    also if sle_version is not set (6.X+)
* Wed Mar 27 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240327.09add4e:
  * Set higher prio for Slowroll update repo
  * Re-use TW Nvidia repo for Slowroll
  * Add slowroll repos
  * LeapMicro cleanup of repo-main.repo
* Thu Aug 10 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230810.a7534f6:
  * Disable NVIDIA pkg building on LeapMicro. Fixes #34
    PM confirmed that NVIDIA related deployments are expected
    to have all drivers/tools inside of container.
  * Fix incorrect with_nvidia usage
* Fri Aug  4 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230804.41e41a9:
  * Add NVIDIA repo. Issue #28
  * Add supplements for all NVIDIA cards
  * Add NVIDIA obsoletes for migration from Leap 15
  * Add spec comment about suggests in release package
  * Add download.opensuse.org-non-oss.repo in legacy backup list
* Mon Jul 31 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230731.a018a46:
  * Use HTTP - When you use https, you have the tls handshake overhead
    and you get redirected to only-https mirrors.
    Also http by default enables systems with experimental ssl setup.
  * Update README.md with text from the news-o-o article
* Tue Jul 25 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230725.c6c492e:
  * rephrase README
  * Keep backup of legacy files as .rpmsave
  * Use cdn-o-o instead of downloadcontentcdn-o-o
  * openSUSE-repos adaptation of CDN
  * improve comment on Leap16 handling
  * Build -Leap16 on ALP/TW like build env
  * correct flavor of Leap16
  * Add Leap 16.0 definitions
* Thu Feb  9 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230209.87a5e9e:
  * Drop obsoleting of TW from openSUSE-repos-MicroOS
  * Do not use distver for TW and MicroOS openh264 repo
* Mon Jan 23 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230123.088570b:
  * Use http as the redirect target does not support https
  * Add openh264 repos as enabled by default
* Wed Nov 16 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221116.d3d7bc7:
  * Use zypp style variable for DIST_ARCH boo#1205460
  * Remove service generated service file on uninstall
* Wed Nov  2 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221103.b904c44:
  * drop dependency on suse-release
* Wed Oct 12 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221012.1c71da6:
  * Remove trailing endif
* Wed Oct 12 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221012.07c2eae:
  * MicroOS should builds on Factory version only
* Wed Oct 12 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221012.ea3218c:
  * Ensure that MicroOS flavor is not build on Leap
* Wed Oct 12 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221012.c4167e1:
  * fix broken spec
  * Remove unwanted second spec
  * Rebase MicroOS on top of single-spec setup
  * Initial MicroOS flavor based on TW
* Fri Oct  7 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221007.638a03b:
  * Packaging: set default package name as openSUSE-repos for non-flavour
* Fri Oct  7 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221007.0e44106:
  * Packaging: made it to be real multibuild
* Mon Sep 26 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220926.da3133a:
  * Corrected path and name for LeapMicro debug repo
* Mon Sep 26 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220926.c75597d:
  * Run spec-cleaner on specs
* Mon Sep 26 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220926.e27264d:
  * Add LeapMicro
* Mon Sep 26 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220926.be4cbf8:
  * Specs for multibuild support as we have >2 flavors
* Sat Sep 24 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220924.5761673:
  * requested in https://code.opensuse.org/leap/features/issue/91
  * Disable post-build checks due to boo#1203715
  * Initial rpm spec logic is based on rpm-repos-openSUSE from Neal
